@@ -130,9 +130,12 @@ def get_vertical_position(frame_width_input, frame_height_input, put_text_input,
     x_edit = int(frame_height_input - y_input)
     y_edit = x_input
     co_ord_input = (x_edit, y_edit)
+    # draw
     cv2.putText(tem_image, put_text_input, co_ord_input, cv2.FONT_HERSHEY_SIMPLEX, font_input,
                 color_search_input, thick_input)
+    # rotate
     out_image = cv2.rotate(tem_image, cv2.ROTATE_90_COUNTERCLOCKWISE)
+    # capture position to return
     color_index_output = np.where(np.all(out_image == color_search_input, axis=-1))
 
     return color_index_output
@@ -257,7 +260,7 @@ def get_value_from_array(data_arr_input, low_li, up_li):
 
 def main():
     parser = argparse.ArgumentParser(prog='vinset', description='VINSET package.')
-    parser.add_argument('--version', action='version', version='3.0.4'),
+    parser.add_argument('--version', action='version', version='3.0.5'),
     parser.add_argument("-i", dest="input_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="input mp4 file", metavar="filename.mp4")
     parser.add_argument("-d", dest="input_data_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
@@ -267,12 +270,14 @@ def main():
     parser.add_argument("-c", dest="config_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="config json file", metavar="filename.json")
 
+    # get all input name in string
     args = parser.parse_args()
     input_file = args.input_filename.name
     csv_data = args.input_data_filename.name
     output_file = args.output_filename.name
     config_file = args.config_filename.name
 
+    # start whether the inputs are in correct types or not
     if str(input_file).endswith(".mp4"):
         print("Input file name:", input_file)
     else:
@@ -319,6 +324,7 @@ def main():
         pointer_info_dict = {}
         max_video_length = math.ceil(frame_count_to_time(frame_count, frame_rate))
 
+        # for loop over series array and prepare the respected data
         for info in series_array:
             search_string = info["parent_axes"]
             parent_index = get_position_of_parent(search_string, axes_array)
@@ -346,15 +352,21 @@ def main():
                 if info_filter:
                     filter_by = info["filterBy"]
                 if str(display_type).lower() == "pen":
+                    # getting data from csv with or without filter
                     if info_filter:
                         data_arr = get_data_array(csv_data, t_data, y_data, t_offset, info_filter, filter_by)
                     else:
                         data_arr = get_data_array(csv_data, t_data, y_data, t_offset)
                     series_data_array = []
+                    # calculate the max duration of time can be displayed in one pixel
                     time_interval_for_data = round(1000 / (axes_pos_w / t_w), 4)
+                    # calculate how many display for the whole video
                     number_of_time_interval = math.ceil(max_video_length / time_interval_for_data)
+                    # lower range starts with 0 and upper range starts with milliseconds
+                    # calculated from time interval for data
                     lower_range = 0
                     upper_range = round((lower_range + time_interval_for_data), 2)
+                    # calculate the length of 1 display in milliseconds
                     width_check = int(t_w) * 1000
                     box_data_array = []
                     for i in range(1, (number_of_time_interval + 1), 1):
@@ -363,6 +375,7 @@ def main():
                         for data in data_arr:
                             if lower_range <= data[0] < upper_range:
                                 raw_data_array.append(data)
+                        # get the average of value array because we only can draw 1 data at 1 pixel
                         input_data = get_value_from_array(raw_data_array, lower_range, upper_range)
                         box_data_array.append(input_data)
                         if max_video_length <= width_check:
@@ -381,15 +394,21 @@ def main():
                                             "series_data_array": series_data_array})
 
                 elif str(display_type).lower() == "static":
+                    # getting data from csv with or without filter
                     if info_filter:
                         data_arr = get_data_array(csv_data, t_data, y_data, t_offset, info_filter, filter_by)
                     else:
                         data_arr = get_data_array(csv_data, t_data, y_data, t_offset)
                     series_data_array = []
+                    # calculate the max duration of time can be displayed in one pixel
                     time_interval_for_data = round(1000 / (axes_pos_w / t_w), 4)
+                    # calculate how many display for the whole video
                     number_of_time_interval = math.ceil(max_video_length / time_interval_for_data)
+                    # lower range starts with 0 and upper range starts with milliseconds
+                    # calculated from time interval for data
                     lower_range = 0
                     upper_range = round((lower_range + time_interval_for_data), 2)
+                    # calculate the length of 1 display in milliseconds
                     width_check = int(t_w) * 1000
                     box_data_array = []
                     for i in range(1, (number_of_time_interval + 1), 1):
@@ -398,6 +417,7 @@ def main():
                         for data in data_arr:
                             if lower_range <= data[0] < upper_range:
                                 raw_data_array.append(data)
+                        # get the average of value array because we only can draw 1 data at 1 pixel
                         input_data = get_value_from_array(raw_data_array, lower_range, upper_range)
                         raw_data_array.clear()
                         box_data_array.append(input_data)
@@ -419,6 +439,7 @@ def main():
         ret, frame = input_video.read()
         raw_image = None
         if ret:
+            # get the frame and fill with black
             raw_image = frame
             raw_image.fill(0)
         box_color_array = []
@@ -428,13 +449,15 @@ def main():
             parent_index = get_position_of_parent(search_string, axes_array)
             if parent_index is not None:
                 axes_info = axes_array[parent_index]
-                box_color = change_string_to_color_tuple(axes_info["box_color"])
-                box_color_array.append(box_color)
+                box_color = axes_info["box_color"]
                 axes_pos = axes_info["position"]
                 box_title = axes_info["box_title"]
                 title_x_position = axes_info["box_title_x_position"]
                 title_y_position = axes_info["box_title_y_position"]
-                title_color = change_string_to_color_tuple(axes_info["box_title_color"])
+                title_color = axes_info["box_title_color"]
+                box_color_array.append({"box_color": box_color, "title_color": title_color})
+                box_color = change_string_to_color_tuple(box_color)
+                title_color = change_string_to_color_tuple(title_color)
                 title_font = float(axes_info["box_title_font_scale"])
                 box_thickness = int(axes_info["box_thickness"])
                 axes_pos_x = axes_pos["x"]
@@ -451,6 +474,7 @@ def main():
                 y_label_y_position = info["y_label_y_position"]
                 label_thickness = int(info["label_thickness"])
                 label_font_scale = float(info["label_font_scale"])
+                # draw box and labels according to config
                 raw_image = cv2.rectangle(raw_image, (axes_pos_x, axes_pos_y),
                                           ((axes_pos_x + axes_pos_w), (axes_pos_y + axes_pos_h)),
                                           box_color, box_thickness)
@@ -464,9 +488,11 @@ def main():
                             box_color, label_thickness)
                 y_label_x_input = axes_pos_x - int(y_label_x_position)
                 y_label_y_input = axes_pos_y - int(y_label_y_position)
+                # getting the position of vertical label
                 ver_color_index_array = get_vertical_position(frame_width, frame_height, y_name,
                                                               y_label_x_input, y_label_y_input,
                                                               box_color, label_font_scale, label_thickness)
+                # use that position and draw vertical label in raw image
                 for item in zip(ver_color_index_array[0], ver_color_index_array[1]):
                     item_tuple = tuple(item)
                     raw_image[item_tuple[0], item_tuple[1]] = box_color
@@ -476,6 +502,7 @@ def main():
                 # x_scale_level = axes_pos_y + axes_pos_h
                 height_of_scale = 5
 
+                # draw x axis / t axis interval points
                 for i in range(0, t_w):
                     space_value = i * x_scale_interval_width
                     # end_point_x_scale_level = start_point_x_scale - height_of_scale
@@ -484,11 +511,8 @@ def main():
                              (axes_pos_x + space_value,
                               axes_pos_h + axes_pos_y - height_of_scale),
                              box_color, box_thickness)
-
-        draw_index_arr = []
-        for color in box_color_array:
-            draw_index = get_color_position(raw_image, color)
-            draw_index_arr.append(draw_index)
+                # after this points, the raw black image is filled with
+                # all graphs and labels
 
         fourcc = cv2.VideoWriter_fourcc(*'mp4v')
         v_writer = cv2.VideoWriter(output_file, fourcc, int(frame_rate), (int(frame_width), int(frame_height)))
@@ -519,22 +543,37 @@ def main():
                         bg_fill = axes_bg["fill"]
                         color_input = change_string_to_color_tuple(bg_fill)
                         bg_opacity = axes_bg["opacity"]
+                        # copy a frame to draw boundary
                         overlay_frame = frame.copy()
                         boundary_space = 50
+                        # draw boundary to graph
                         cv2.rectangle(overlay_frame,
                                       (x - boundary_space, y - boundary_space),
                                       (x + w + boundary_space,
                                        y + h + boundary_space),
                                       color_input, -1)
+                        # overlay by original frame
                         frame = cv2.addWeighted(overlay_frame, bg_opacity,
                                                 frame, 1 - bg_opacity, 0)
-                for i, d_index in enumerate(draw_index_arr):
-                    for item in zip(d_index[0], d_index[1]):
-                        item_tuple = tuple(item)
-                        frame[item_tuple[0], item_tuple[1]] = box_color_array[i]
+                        # draw graphs and labels over the frame
+                        # to avoid color opacity drops
+                        for color in box_color_array:
+                            box_color = change_string_to_color_tuple(color["box_color"])
+                            title_color = change_string_to_color_tuple(color["title_color"])
+                            box_draw_index = get_color_position(raw_image, box_color)
+                            title_draw_index = get_color_position(raw_image, title_color)
+
+                            for box_item in zip(box_draw_index[0], box_draw_index[1]):
+                                box_item_tuple = tuple(box_item)
+                                frame[box_item_tuple[0], box_item_tuple[1]] = box_color
+
+                            for title_item in zip(title_draw_index[0], title_draw_index[1]):
+                                title_item_tuple = tuple(title_item)
+                                frame[title_item_tuple[0], title_item_tuple[1]] = title_color
 
                 clone_frame = np.copy(frame)
 
+                # for loop and draw the data on the clone frame
                 for info in series_array:
                     if len(draw_data_array) > 0:
                         info_name = info["name"]
@@ -747,7 +786,9 @@ def main():
                         y = axes_pos["y"]
                         w = axes_pos["width"]
                         h = axes_pos["height"]
+                        # crop the clone frame to get the graph box
                         cropped_image = clone_frame[y:(y + h), x:(x + w)]
+                        # replace on the original frame in order to avoid over drawn
                         frame[y:(y + h), x:(x + w)] = cropped_image
 
                 if display_able:
